<?php
/**
 * oicon functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package oicon
 */

if ( ! function_exists( 'oicon_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function oicon_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on oicon, use a find and replace
	 * to change 'oicon' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'oicon', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'menu-principal' => esc_html__( 'Main Menu', 'oicon' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'oicon_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'oicon_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function oicon_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'oicon_content_width', 640 );
}
add_action( 'after_setup_theme', 'oicon_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function oicon_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'oicon' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
		register_sidebar( array(
		'name' => 'Footer 1',
		'id' => 'footer-widget-1',
		'description' => 'Appears in the footer area',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
		) );
		register_sidebar( array(
		'name' => 'Footer 2',
		'id' => 'footer-widget-2',
		'description' => 'Appears in the footer area',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
		) );
		register_sidebar( array(
		'name' => 'Footer 3',
		'id' => 'footer-widget-3',
		'description' => 'Appears in the footer area',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
		) );
	
}
add_action( 'widgets_init', 'oicon_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function oicon_scripts() {
	wp_enqueue_style( 'oicon-bootstrap-style', '//maxcdn.bootstrapcdn.com/bootstrap/3.3.6/css/bootstrap.min.css' );

	wp_enqueue_style( 'oicon-style', get_stylesheet_uri() );
	
	wp_enqueue_style( 'custom-oicon', get_template_directory_uri() . '/inc/css/custom-oicon.css' );
	
	wp_enqueue_style( 'media-queries', get_template_directory_uri() . '/inc/css/media-queries.css' );
	
	wp_enqueue_script( 'signos-bootstrap-script', 'https://maxcdn.bootstrapcdn.com/bootstrap/3.3.6/js/bootstrap.min.js', array(), '20120206', true );
	
    wp_enqueue_script( 'signos-fontawesome-script', 'https://use.fontawesome.com/505820e873.js	', array(), '20120206', true );

}
add_action( 'wp_enqueue_scripts', 'oicon_scripts', 18 );

/*************** Tiny MCE ***************/
function override_mce_options($initArray) {
	$opts = '*[*]';
	$initArray['valid_elements'] = $opts;
	$initArray['extended_valid_elements'] = $opts;
return $initArray;} add_filter('tiny_mce_before_init', 'override_mce_options');    


/*************** Opciones ACF ***************/
if( function_exists('acf_add_options_page') ) {
	acf_add_options_page();
}

/*************** Custom-header ***************/
function oicon_custom_header_setup() {
    $args = array(
		'default-image'     => 'http://placehold.it/1100x350',
		'width'				=> 856, 
		'height'				=> 300, 
        'flex-width'        => true,
        'flex-height'       => true,
    );
    add_theme_support( 'custom-header', $args );
}
add_action( 'after_setup_theme', 'oicon_custom_header_setup' );


function shortcode_oicon_header() {
	?>
		<div class="custom-header"><img src="<?php header_image(); ?>" height="300"></div>
	<?php
}
add_shortcode('oicon_header', 'shortcode_oicon_header');

function oicon_add_excerpts_to_pages() {
     add_post_type_support( 'page', 'excerpt' );
}
add_action( 'init', 'oicon_add_excerpts_to_pages' );

